You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by ra...@apache.org on 2009/07/16 05:25:30 UTC

svn commit: r794504 - in /commons/proper/scxml/branches/J6: ./ src/main/java/org/apache/commons/scxml/ src/main/java/org/apache/commons/scxml/env/ src/main/java/org/apache/commons/scxml/invoke/ src/main/java/org/apache/commons/scxml/io/ src/main/java/o...

Author: rahul
Date: Thu Jul 16 03:25:20 2009
New Revision: 794504

URL: http://svn.apache.org/viewvc?rev=794504&view=rev
Log:
Port r794503 from trunk.
Attribute "targettype" of the <send> and <invoke> elements changed to "type" in latest Working Draft.
Thanks to patch by Ales Dolecek <ales_d at seznam dot cz>.
Also added Ales to the contributors list.
SCXML-109

Modified:
    commons/proper/scxml/branches/J6/pom.xml
    commons/proper/scxml/branches/J6/project.xml
    commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/EventDispatcher.java
    commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/SCInstance.java
    commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/SCXMLExecutor.java
    commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/env/SimpleDispatcher.java
    commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/env/SimpleScheduler.java
    commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/invoke/Invoker.java
    commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/ModelUpdater.java
    commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/SCXMLReader.java
    commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/SCXMLSerializer.java
    commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/SCXMLWriter.java
    commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/model/Invoke.java
    commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/model/Send.java
    commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/semantics/SCXMLSemanticsImpl.java
    commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/SCXMLExecutorTest.java
    commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/WizardsTest.java
    commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/env/jexl/wizard-02.xml
    commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoked-03.xml
    commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-01.xml
    commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-02.xml
    commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-03.xml
    commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-04.xml
    commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/io/SCXMLSerializerTest.java
    commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/model/actions-initial-test.xml
    commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/model/actions-parallel-test.xml
    commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/model/actions-state-test.xml
    commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/send-01.xml
    commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/send-02.xml
    commons/proper/scxml/branches/J6/xdocs/changes.xml
    commons/proper/scxml/branches/J6/xdocs/guide/core-engine.xml
    commons/proper/scxml/branches/J6/xdocs/guide/using-commons-scxml.xml

Modified: commons/proper/scxml/branches/J6/pom.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/pom.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/pom.xml (original)
+++ commons/proper/scxml/branches/J6/pom.xml Thu Jul 16 03:25:20 2009
@@ -120,6 +120,9 @@
     <contributor>
       <name>Joel Truher</name>
     </contributor>
+    <contributor>
+      <name>Ales Dolecek</name>
+    </contributor>
   </contributors>
 
   <dependencies>

Modified: commons/proper/scxml/branches/J6/project.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/project.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/project.xml (original)
+++ commons/proper/scxml/branches/J6/project.xml Thu Jul 16 03:25:20 2009
@@ -172,6 +172,9 @@
     <contributor>
       <name>Joel Truher</name>
     </contributor>
+    <contributor>
+      <name>Ales Dolecek</name>
+    </contributor>
   </contributors>
   
   <dependencies>

Modified: commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/EventDispatcher.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/EventDispatcher.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/EventDispatcher.java (original)
+++ commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/EventDispatcher.java Thu Jul 16 03:25:20 2009
@@ -42,8 +42,8 @@
      *
      * @param sendId The ID of the send message
      * @param target An expression returning the target location of the event
-     * @param targetType The type of the Event I/O Processor that the event
-     *  should be dispatched to
+     * @param type The type of the Event I/O Processor that the event should
+     *  be dispatched to
      * @param event The type of event being generated.
      * @param params A list of zero or more whitespace separated variable
      *  names to be included with the event.
@@ -53,7 +53,7 @@
      * @param externalNodes The list of external nodes associated with
      *  the &lt;send&gt; element.
      */
-    void send(String sendId, String target, String targetType,
+    void send(String sendId, String target, String type,
             String event, Map<String, Object> params, Object hints,
             long delay, List<Node> externalNodes);
 

Modified: commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/SCInstance.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/SCInstance.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/SCXMLExecutor.java (original)
+++ commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/SCXMLExecutor.java Thu Jul 16 03:25:20 2009
@@ -436,24 +436,24 @@
     /**
      * Register an <code>Invoker</code> for this target type.
      *
-     * @param targettype The target type (specified by "targettype"
-     *                   attribute of &lt;invoke&gt; tag).
+     * @param type The target type (specified by "type"
+     *             attribute of &lt;invoke&gt; tag).
      * @param invokerClass The <code>Invoker</code> <code>Class</code>.
      */
-    public void registerInvokerClass(final String targettype,
+    public void registerInvokerClass(final String type,
             final Class<? extends Invoker> invokerClass) {
-        scInstance.registerInvokerClass(targettype, invokerClass);
+        scInstance.registerInvokerClass(type, invokerClass);
     }
 
     /**
      * Remove the <code>Invoker</code> registered for this target
      * type (if there is one registered).
      *
-     * @param targettype The target type (specified by "targettype"
-     *                   attribute of &lt;invoke&gt; tag).
+     * @param type The target type (specified by "type"
+     *             attribute of &lt;invoke&gt; tag).
      */
-    public void unregisterInvokerClass(final String targettype) {
-        scInstance.unregisterInvokerClass(targettype);
+    public void unregisterInvokerClass(final String type) {
+        scInstance.unregisterInvokerClass(type);
     }
 
     /**

Modified: commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/env/SimpleDispatcher.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/env/SimpleDispatcher.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/env/SimpleDispatcher.java (original)
+++ commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/env/SimpleDispatcher.java Thu Jul 16 03:25:20 2009
@@ -57,14 +57,14 @@
     @see EventDispatcher#send(String,String,String,String,Map,Object,long,List)
      */
     public void send(final String sendId, final String target,
-            final String targetType, final String event,
+            final String type, final String event,
             final Map<String, Object> params, final Object hints, final long delay,
             final List<Node> externalNodes) {
         if (log.isInfoEnabled()) {
             StringBuffer buf = new StringBuffer();
             buf.append("send ( sendId: ").append(sendId);
             buf.append(", target: ").append(target);
-            buf.append(", targetType: ").append(targetType);
+            buf.append(", type: ").append(type);
             buf.append(", event: ").append(event);
             buf.append(", params: ").append(String.valueOf(params));
             buf.append(", hints: ").append(String.valueOf(hints));

Modified: commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/env/SimpleScheduler.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/env/SimpleScheduler.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/env/SimpleScheduler.java (original)
+++ commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/env/SimpleScheduler.java Thu Jul 16 03:25:20 2009
@@ -35,15 +35,15 @@
 
 /**
  * <p>EventDispatcher implementation that can schedule <code>delay</code>ed
- * &lt;send&gt; events for the &quot;scxml&quot; <code>targettype</code>
+ * &lt;send&gt; events for the &quot;scxml&quot; <code>type</code>
  * attribute value (which is also the default). This implementation uses
  * J2SE <code>Timer</code>s.</p>
  *
- * <p>No other <code>targettype</code>s are processed. Subclasses may support
- * additional <code>targettype</code>s by overriding the
+ * <p>No other <code>type</code>s are processed. Subclasses may support
+ * additional <code>type</code>s by overriding the
  * <code>send(...)</code> and <code>cancel(...)</code> methods and
  * delegating to their <code>super</code> counterparts for the
- * &quot;scxml&quot; <code>targettype</code>.</p>
+ * &quot;scxml&quot; <code>type</code>.</p>
  *
  */
 public class SimpleScheduler implements EventDispatcher, Serializable {
@@ -102,7 +102,7 @@
     @see EventDispatcher#send(String,String,String,String,Map,Object,long,List)
      */
     public void send(final String sendId, final String target,
-            final String targettype, final String event,
+            final String type, final String event,
             final Map<String, Object> params, final Object hints, final long delay,
             final List<Node> externalNodes) {
         // Log callback
@@ -110,7 +110,7 @@
             StringBuffer buf = new StringBuffer();
             buf.append("send ( sendId: ").append(sendId);
             buf.append(", target: ").append(target);
-            buf.append(", targetType: ").append(targettype);
+            buf.append(", type: ").append(type);
             buf.append(", event: ").append(event);
             buf.append(", params: ").append(String.valueOf(params));
             buf.append(", hints: ").append(String.valueOf(hints));
@@ -119,9 +119,9 @@
             log.info(buf.toString());
         }
 
-        // We only handle the "scxml" targettype (which is the default too)
-        if (SCXMLHelper.isStringEmpty(targettype)
-                || targettype.trim().equalsIgnoreCase(TARGETTYPE_SCXML)) {
+        // We only handle the "scxml" type (which is the default too)
+        if (SCXMLHelper.isStringEmpty(type)
+                || type.trim().equalsIgnoreCase(TYPE_SCXML)) {
 
             if (!SCXMLHelper.isStringEmpty(target)) {
                 // We know of no other target
@@ -249,9 +249,9 @@
     }
 
     /**
-     * The default targettype.
+     * The default target type.
      */
-    private static final String TARGETTYPE_SCXML = "scxml";
+    private static final String TYPE_SCXML = "scxml";
 
     /**
      * The spec mandated derived event when target cannot be reached.

Modified: commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/invoke/Invoker.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/invoke/Invoker.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/invoke/Invoker.java (original)
+++ commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/invoke/Invoker.java Thu Jul 16 03:25:20 2009
@@ -27,7 +27,7 @@
  * activities.</p>
  *
  * <p>Invocable activities must first register an Invoker implementation class
- * for the appropriate "targettype" (attribute of &lt;invoke&gt;) with the
+ * for the appropriate "target" (attribute of &lt;invoke&gt;) with the
  * parent <code>SCXMLExecutor</code>.</p>
  *
  * <p>The communication link between the parent state machine executor and
@@ -35,16 +35,16 @@
  *
  * <p>All events triggered on the parent state machine get forwarded to the
  * invoked activity. The processing semantics for these events depend
- * upon the "targettype", and thereby vary per concrete implementation of
+ * upon the "target", and thereby vary per concrete implementation of
  * this interface.</p>
  *
  * <p>The invoked activity in turn must fire a special "done" event
  * when it concludes. It may fire additional events before the "done"
  * event. The semantics of any additional events depend upon the
- * "targettype". The invoked activity must not fire any events after the
- * "done" event. The name of the special "done" event must be
- * the ID of the parent state wherein the corresponding &lt;invoke&gt;
- * resides, with the String ".invoke.done" appended.</p>
+ * "target". The invoked activity must not fire any events after the "done"
+ * event. The name of the special "done" event must be the ID of the parent
+ * state wherein the corresponding &lt;invoke&gt; resides, with the String
+ * ".invoke.done" appended.</p>
  *
  * <p>The Invoker "lifecycle" is outlined below:
  *  <ol>

Modified: commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/ModelUpdater.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/ModelUpdater.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/SCXMLReader.java (original)
+++ commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/SCXMLReader.java Thu Jul 16 03:25:20 2009
@@ -239,7 +239,6 @@
     private static final String ATTR_SENDID = "sendid";
     private static final String ATTR_SRC = "src";
     private static final String ATTR_TARGET = "target";
-    private static final String ATTR_TARGETTYPE = "targettype";
     private static final String ATTR_TYPE = "type";
     private static final String ATTR_VERSION = "version";
 
@@ -1083,7 +1082,7 @@
 
         Invoke invoke = new Invoke();
         invoke.setSrc(readAV(reader, ATTR_SRC));
-        invoke.setTargettype(readAV(reader, ATTR_TARGETTYPE));
+        invoke.setType(readAV(reader, ATTR_TYPE));
         invoke.setPathResolver(configuration.pathResolver);
         readNamespaces(configuration, invoke);
 
@@ -1650,7 +1649,7 @@
         send.setNamelist(readAV(reader, ATTR_NAMELIST));
         send.setSendid(readAV(reader, ATTR_SENDID));
         send.setTarget(readAV(reader, ATTR_TARGET));
-        send.setTargettype(readAV(reader, ATTR_TARGETTYPE));
+        send.setType(readAV(reader, ATTR_TYPE));
         readNamespaces(configuration, send);
 
         Node body = readNode(reader, configuration, XMLNS_SCXML, ELEM_SEND, new String [] {});

Modified: commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/SCXMLSerializer.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/SCXMLSerializer.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/SCXMLSerializer.java (original)
+++ commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/SCXMLSerializer.java Thu Jul 16 03:25:20 2009
@@ -213,11 +213,11 @@
     public static void serializeInvoke(final StringBuffer b,
             final Invoke i, final String indent) {
         b.append(indent).append("<invoke");
-        String ttype = i.getTargettype();
+        String type = i.getType();
         String src = i.getSrc();
         String srcexpr = i.getSrcexpr();
-        if (ttype != null) {
-            b.append(" targettype=\"").append(ttype).append("\"");
+        if (type != null) {
+            b.append(" type=\"").append(type).append("\"");
         }
         // Prefer src
         if (src != null) {
@@ -480,8 +480,8 @@
         if (send.getTarget() != null) {
             b.append(" target=\"").append(send.getTarget()).append("\"");
         }
-        if (send.getTargettype() != null) {
-            b.append(" targetType=\"").append(send.getTargettype()).append("\"");
+        if (send.getType() != null) {
+            b.append(" targetType=\"").append(send.getType()).append("\"");
         }
         if (send.getNamelist() != null) {
             b.append(" namelist=\"").append(send.getNamelist()).append("\"");

Modified: commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/SCXMLWriter.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/SCXMLWriter.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/SCXMLWriter.java (original)
+++ commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/SCXMLWriter.java Thu Jul 16 03:25:20 2009
@@ -172,7 +172,6 @@
     private static final String ATTR_SENDID = "sendid";
     private static final String ATTR_SRC = "src";
     private static final String ATTR_TARGET = "target";
-    private static final String ATTR_TARGETTYPE = "targettype";
     private static final String ATTR_TYPE = "type";
     private static final String ATTR_VERSION = "version";
 
@@ -724,7 +723,7 @@
 
         writer.writeStartElement(ELEM_INVOKE);
         writeAV(writer, ATTR_SRC, invoke.getSrc());
-        writeAV(writer, ATTR_TARGETTYPE, invoke.getTargettype());
+        writeAV(writer, ATTR_TYPE, invoke.getType());
 
         for (Param p : invoke.params()) {
             writer.writeStartElement(ELEM_PARAM);
@@ -847,7 +846,7 @@
         writeAV(writer, ATTR_SENDID, send.getSendid());
         writeAV(writer, ATTR_EVENT, send.getEvent());
         writeAV(writer, ATTR_TARGET, send.getTarget());
-        writeAV(writer, ATTR_TARGETTYPE, send.getTargettype());
+        writeAV(writer, ATTR_TYPE, send.getType());
         writeAV(writer, ATTR_DELAY, send.getDelay());
         writeAV(writer, ATTR_NAMELIST, send.getNamelist());
         writeAV(writer, ATTR_HINTS, send.getHints());

Modified: commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/model/Invoke.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/model/Invoke.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/model/Invoke.java (original)
+++ commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/model/Invoke.java Thu Jul 16 03:25:20 2009
@@ -40,7 +40,7 @@
     /**
      * The type of target to be invoked.
      */
-    private String targettype;
+    private String type;
 
     /**
      * The source URL for the external service.
@@ -85,18 +85,38 @@
      * Get the target type for this &lt;invoke&gt; element.
      *
      * @return String Returns the targettype.
+     * @deprecated Use {@link #getType()} instead.
      */
     public final String getTargettype() {
-        return targettype;
+        return type;
     }
 
     /**
      * Set the target type for this &lt;invoke&gt; element.
      *
      * @param targettype The targettype to set.
+     * @deprecated Use {@link #setType(String)} instead.
      */
     public final void setTargettype(final String targettype) {
-        this.targettype = targettype;
+        this.type = targettype;
+    }
+
+    /**
+     * Get the type for this &lt;invoke&gt; element.
+     *
+     * @return String Returns the type.
+     */
+    public final String getType() {
+        return type;
+    }
+
+    /**
+     * Set the type for this &lt;invoke&gt; element.
+     *
+     * @param type The type to set.
+     */
+    public final void setType(final String type) {
+        this.type = type;
     }
 
     /**

Modified: commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/model/Send.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/model/Send.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/model/Send.java (original)
+++ commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/model/Send.java Thu Jul 16 03:25:20 2009
@@ -48,13 +48,13 @@
     private static final long serialVersionUID = 1L;
 
     /**
-     * The default targettype.
+     * The default target type.
      */
-    private static final String TARGETTYPE_SCXML = "scxml";
+    private static final String TYPE_SCXML = "scxml";
 
     /**
      * The spec mandated derived event when target cannot be reached
-     * for TARGETTYPE_SCXML.
+     * for TYPE_SCXML.
      */
     private static final String EVENT_ERR_SEND_TARGETUNAVAILABLE =
         "error.send.targetunavailable";
@@ -73,7 +73,7 @@
      * The type of the Event I/O Processor that the event.
      * should be dispatched to
      */
-    private String targettype;
+    private String type;
 
     /**
      * The event is dispatched after the delay interval elapses.
@@ -230,19 +230,39 @@
     /**
      * Get the target type for this &lt;send&gt; element.
      *
-     * @return String Returns the targettype.
+     * @return String Returns the type.
+     * @deprecated Use {@link #getType()} instead.
      */
     public final String getTargettype() {
-        return targettype;
+        return type;
     }
 
     /**
      * Set the target type for this &lt;send&gt; element.
      *
-     * @param targettype The targettype to set.
+     * @param type The type to set.
+     * @deprecated Use {@link #setType(String)} instead.
      */
     public final void setTargettype(final String targettype) {
-        this.targettype = targettype;
+        this.type = targettype;
+    }
+
+    /**
+     * Get the type for this &lt;send&gt; element.
+     *
+     * @return String Returns the type.
+     */
+    public final String getType() {
+        return type;
+    }
+
+    /**
+     * Set the type for this &lt;send&gt; element.
+     *
+     * @param type The type to set.
+     */
+    public final void setType(final String type) {
+        this.type = type;
     }
 
     /**
@@ -291,17 +311,17 @@
                     + "\" evaluated to null or empty String");
             }
         }
-        String targettypeValue = targettype;
-        if (!SCXMLHelper.isStringEmpty(targettype)) {
-            targettypeValue = (String) eval.eval(ctx, targettype);
-            if (SCXMLHelper.isStringEmpty(targettypeValue)
+        String typeValue = type;
+        if (!SCXMLHelper.isStringEmpty(type)) {
+            typeValue = (String) eval.eval(ctx, type);
+            if (SCXMLHelper.isStringEmpty(typeValue)
                     && appLog.isWarnEnabled()) {
-                appLog.warn("<send>: targettype expression \"" + targettype
+                appLog.warn("<send>: type expression \"" + type
                     + "\" evaluated to null or empty String");
             }
         } else {
             // must default to 'scxml' when unspecified
-            targettypeValue = TARGETTYPE_SCXML;
+            typeValue = TYPE_SCXML;
         }
         Map<String, Object> params = null;
         if (!SCXMLHelper.isStringEmpty(namelist)) {
@@ -336,8 +356,8 @@
             }
         }
         // Lets see if we should handle it ourselves
-        if (targettypeValue != null
-              && targettypeValue.trim().equalsIgnoreCase(TARGETTYPE_SCXML)) {
+        if (typeValue != null
+              && typeValue.trim().equalsIgnoreCase(TYPE_SCXML)) {
             if (SCXMLHelper.isStringEmpty(targetValue)) {
                 // TODO: Remove both short-circuit passes in v1.0
                 if (wait == 0L) {
@@ -366,11 +386,11 @@
         if (appLog.isDebugEnabled()) {
             appLog.debug("<send>: Dispatching event '" + eventValue
                 + "' to target '" + targetValue + "' of target type '"
-                + targettypeValue + "' with suggested delay of " + wait
+                + typeValue + "' with suggested delay of " + wait
                 + "ms");
         }
         // Else, let the EventDispatcher take care of it
-        evtDispatcher.send(sendid, targetValue, targettypeValue, eventValue,
+        evtDispatcher.send(sendid, targetValue, typeValue, eventValue,
             params, hintsValue, wait, externalNodes);
     }
 

Modified: commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/semantics/SCXMLSemanticsImpl.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/semantics/SCXMLSemanticsImpl.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/semantics/SCXMLSemanticsImpl.java (original)
+++ commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/semantics/SCXMLSemanticsImpl.java Thu Jul 16 03:25:20 2009
@@ -762,10 +762,10 @@
                 if (pr != null) {
                     source = i.getPathResolver().resolvePath(src);
                 }
-                String ttype = i.getTargettype();
+                String type = i.getType();
                 Invoker inv = null;
                 try {
-                    inv = scInstance.newInvoker(ttype);
+                    inv = scInstance.newInvoker(type);
                 } catch (InvokerException ie) {
                     TriggerEvent te = new TriggerEvent(s.getId()
                         + ".invoke.failed", TriggerEvent.ERROR_EVENT);

Modified: commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/SCXMLExecutorTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/SCXMLExecutorTest.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/SCXMLExecutorTest.java (original)
+++ commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/SCXMLExecutorTest.java Thu Jul 16 03:25:20 2009
@@ -256,7 +256,7 @@
         assertEquals("twenty", currentStates.iterator().next().getId());
     }
 
-    public void testSend02TargettypeSCXMLSample() throws Exception {
+    public void testSend02TypeSCXMLSample() throws Exception {
         exec = SCXMLTestHelper.getExecutor(send02);
         assertNotNull(exec);
         Set<TransitionTarget> currentStates = exec.getCurrentStatus().getStates();

Modified: commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/WizardsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/WizardsTest.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/WizardsTest.java (original)
+++ commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/WizardsTest.java Thu Jul 16 03:25:20 2009
@@ -120,7 +120,7 @@
         private static final long serialVersionUID = 1L;
         // If you change this, you must also change testWizard02Sample()
         int callback = 0;
-        public void send(String sendId, String target, String targetType,
+        public void send(String sendId, String target, String type,
                 String event, Map<String, Object> params, Object hints, long delay,
                 List<Node> externalNodes) {
             int i = ((Integer) params.get("aValue")).intValue();

Modified: commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/env/jexl/wizard-02.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/env/jexl/wizard-02.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/env/jexl/wizard-02.xml (original)
+++ commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/env/jexl/wizard-02.xml Thu Jul 16 03:25:20 2009
@@ -21,7 +21,7 @@
        initial="state1">
      <state id="state1">
            <onentry>
-                 <!-- Send without a targettype causes the
+                 <!-- Send without a type causes the
                       default to be chosen as "scxml".
                       This will cause the first transition
                       to state2 to be immediately followed. -->
@@ -35,11 +35,11 @@
            <onentry>
                  <cs:var name="aValue" expr="2"/>
                  <!-- Send with a non-empty (and not "scxml")
-                      targettype causes the callback on the
+                      type causes the callback on the
                       EventDispatcher implementation. See
                       testWizard02Sample() in WizardsTest
                       (org.apache.commons.scxml test package) -->
-                 <send namelist="aValue" targettype="'foo'" />
+                 <send namelist="aValue" type="'foo'" />
            </onentry>
            <transition event="event1" target="state1"/>
            <transition event="event3" target="state3"/>
@@ -48,7 +48,7 @@
      <state id="state3">
            <onentry>
                  <cs:var name="aValue" expr="3"/>
-                 <send namelist="aValue" targettype="'foo'" />
+                 <send namelist="aValue" type="'foo'" />
            </onentry>
            <transition event="event1" target="state1"/>
            <transition event="event2" target="state2"/>
@@ -57,7 +57,7 @@
      <state id="state4">
            <onentry>
                  <cs:var name="aValue" expr="4"/>
-                 <send namelist="aValue" targettype="'foo'" />
+                 <send namelist="aValue" type="'foo'" />
            </onentry>
            <transition event="event1" target="state1"/>
            <transition event="event2" target="state2"/>

Modified: commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoked-03.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoked-03.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoked-03.xml (original)
+++ commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoked-03.xml Thu Jul 16 03:25:20 2009
@@ -24,7 +24,7 @@
         <onentry>
             <log expr="'  Outer invoke ...'"/>
         </onentry>
-        <invoke targettype="scxml" src="invoked-03-01.xml"/>
+        <invoke type="scxml" src="invoked-03-01.xml"/>
         <transition event="state1.next" target="end1" />
     </state>
 

Modified: commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-01.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-01.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-01.xml (original)
+++ commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-01.xml Thu Jul 16 03:25:20 2009
@@ -23,7 +23,7 @@
         <onentry>
             <log expr="'Begin invoke test ...'" />
         </onentry>
-        <invoke targettype="scxml" src="invoked-01.xml">
+        <invoke type="scxml" src="invoked-01.xml">
             <param name="foo" expr="'foo'" />
             <param name="bar" expr="'bar'" />
             <finalize>

Modified: commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-02.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-02.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-02.xml (original)
+++ commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-02.xml Thu Jul 16 03:25:20 2009
@@ -20,7 +20,7 @@
        initial="invoker">
 
     <state id="invoker">
-        <invoke targettype="scxml" src="invoked-02.xml"/>
+        <invoke type="scxml" src="invoked-02.xml"/>
         <transition event="invoker.invoke.done" target="end" />
     </state>
 

Modified: commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-03.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-03.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-03.xml (original)
+++ commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-03.xml Thu Jul 16 03:25:20 2009
@@ -24,7 +24,7 @@
         <onentry>
             <log expr="'Invoker ...'"/>
         </onentry>
-        <invoke targettype="scxml" src="invoked-03.xml"/>
+        <invoke type="scxml" src="invoked-03.xml"/>
         <transition event="invoker.invoke.done" target="end">
             <log expr="'  Outer invoke completed'"/>
         </transition>

Modified: commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-04.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-04.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-04.xml (original)
+++ commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/invoke/invoker-04.xml Thu Jul 16 03:25:20 2009
@@ -34,21 +34,21 @@
     </state>
     
     <state id="first">
-        <invoke src="FirstTestSrc" targettype="x-test">
+        <invoke src="FirstTestSrc" type="x-test">
             <param name="ding" expr="Data(foo,'node()')"/>   
         </invoke>
         <transition event="test.trigger" target="second"/>
     </state>
 
     <state id="second">
-        <invoke src="SecondTestSrc" targettype="x-test">
+        <invoke src="SecondTestSrc" type="x-test">
             <param name="Data(foo,'node()')"/>   
         </invoke>
         <transition event="test.trigger" target="third"/>
     </state>
     
     <state id="third">
-        <invoke src="ThirdTestSrc" targettype="x-test">
+        <invoke src="ThirdTestSrc" type="x-test">
             <param name="Data(foo,'gibberish')"/>   
         </invoke>
     </state>

Modified: commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/io/SCXMLSerializerTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/io/SCXMLSerializerTest.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/io/SCXMLSerializerTest.java (original)
+++ commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/io/SCXMLSerializerTest.java Thu Jul 16 03:25:20 2009
@@ -83,7 +83,7 @@
         Send send = new Send();
         send.setSendid("1");
         send.setTarget("newTarget");
-        send.setTargettype("newTargetType");
+        send.setType("newType");
         send.setNamelist("names");
         send.setDelay("4s");
         send.setEvent("turnoff");
@@ -91,7 +91,7 @@
         
         String assertValue = " <send sendid=\"1\" " +
                 "target=\"newTarget\" " +
-                "targetType=\"newTargetType\" " +
+                "targetType=\"newType\" " +
                 "namelist=\"names\" " +
                 "delay=\"4s\" " +
                 "event=\"turnoff\" " +

Modified: commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/model/actions-initial-test.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/model/actions-initial-test.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/model/actions-initial-test.xml (original)
+++ commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/model/actions-initial-test.xml Thu Jul 16 03:25:20 2009
@@ -35,7 +35,7 @@
         </if>
         <cs:var name="drink" expr="water" />
         <cs:var name="eat" expr="flies" />
-        <send sendid="send12345" target="freddy" targettype="frog"
+        <send sendid="send12345" target="freddy" type="frog"
          event="croak" namelist="drink eat" hints="h2o bzz"
          delay="${1000+500}" />
         <cancel sendId="send12345"/>

Modified: commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/model/actions-parallel-test.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/model/actions-parallel-test.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/model/actions-parallel-test.xml (original)
+++ commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/model/actions-parallel-test.xml Thu Jul 16 03:25:20 2009
@@ -34,7 +34,7 @@
       </if>
       <cs:var name="drink" expr="water" />
       <cs:var name="eat" expr="flies" />
-      <send sendid="send12345" target="freddy" targettype="frog"
+      <send sendid="send12345" target="freddy" type="frog"
        event="croak" namelist="drink eat" hints="h2o bzz"
        delay="${1000+500}" />
       <cancel sendId="send12345"/>

Modified: commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/model/actions-state-test.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/model/actions-state-test.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/model/actions-state-test.xml (original)
+++ commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/model/actions-state-test.xml Thu Jul 16 03:25:20 2009
@@ -34,7 +34,7 @@
       </if>
       <cs:var name="drink" expr="water" />
       <cs:var name="eat" expr="flies" />
-      <send sendid="send12345" target="freddy" targettype="frog"
+      <send sendid="send12345" target="freddy" type="frog"
        event="croak" namelist="drink eat" hints="h2o bzz"
        delay="${1000+500}" />
       <cancel sendId="send12345"/>

Modified: commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/send-01.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/send-01.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/send-01.xml (original)
+++ commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/send-01.xml Thu Jul 16 03:25:20 2009
@@ -22,7 +22,7 @@
     <state id="ten">
         <transition event="ten.done" target="twenty">
             <send sendid="send1" delay="'0'"
-             target="'http://localhost:8080/VXMLInterpreter'" targettype="'v3'"
+             target="'http://localhost:8080/VXMLInterpreter'" type="'v3'"
              xmlns:v3="http://foo.bar.com/vxml3"
              xmlns:test="http://my.test.namespace">
                 <v3:form id="Confirm">

Modified: commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/send-02.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/send-02.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/send-02.xml (original)
+++ commons/proper/scxml/branches/J6/src/test/java/org/apache/commons/scxml/send-02.xml Thu Jul 16 03:25:20 2009
@@ -32,21 +32,21 @@
 
     <state id="twenty">
         <onentry>
-            <send event="'twenty.done'" targettype="'scxml'" />
+            <send event="'twenty.done'" type="'scxml'" />
         </onentry>
         <transition event="twenty.done" target="thirty" />
     </state>
 
     <state id="thirty">
         <onentry>
-            <send event="'thirty.done'" targettype="' sCxML  '" />
+            <send event="'thirty.done'" type="' sCxML  '" />
         </onentry>
         <transition event="thirty.done" target="forty" />
     </state>
 
     <state id="forty">
         <onentry>
-            <send event="'forty.done'" targettype=" " target=" " />
+            <send event="'forty.done'" type=" " target=" " />
         </onentry>
         <transition event="forty.done" target="fifty" />
     </state>
@@ -60,14 +60,14 @@
 
     <state id="sixty">
         <onentry>
-            <send event="'sixty.done'" targettype="'scxml'" target=" " />
+            <send event="'sixty.done'" type="'scxml'" target=" " />
         </onentry>
         <transition event="sixty.done" target="seventy" />
     </state>
 
     <state id="seventy">
         <onentry>
-            <send event="'seventy.done'" targettype="'scxml'" target="'foo'" />
+            <send event="'seventy.done'" type="'scxml'" target="'foo'" />
         </onentry>
 
         <!-- This transition should not be followed since

Modified: commons/proper/scxml/branches/J6/xdocs/changes.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/xdocs/changes.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/xdocs/changes.xml (original)
+++ commons/proper/scxml/branches/J6/xdocs/changes.xml Thu Jul 16 03:25:20 2009
@@ -419,7 +419,7 @@
      description="Release">
 
       <action dev="rahul" type="fix" issue="SCXML-16" due-to="Sitthichai Rernglertpricha">
-       [12-12-2006] target and targettype attributes of &lt;send&gt; element
+       [12-12-2006] target and type attributes of &lt;send&gt; element
        are now evaluated as expressions.
       </action>
 
@@ -476,7 +476,7 @@
       <action dev="rahul" type="fix" issue="SCXML-21">
        [10-17-2006] New EventDispatcher implementation (SimpleScheduler)
        that provides the ability to deal with delayed events for the
-       "scxml" &lt;send&gt; targettype.
+       "scxml" &lt;send&gt; type.
       </action>
 
       <action dev="rahul" type="fix" issue="SCXML-2">

Modified: commons/proper/scxml/branches/J6/xdocs/guide/core-engine.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/xdocs/guide/core-engine.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/xdocs/guide/core-engine.xml (original)
+++ commons/proper/scxml/branches/J6/xdocs/guide/core-engine.xml Thu Jul 16 03:25:20 2009
@@ -69,7 +69,7 @@
      <p>Commons SCXML provides an
      <a href="../apidocs/org/apache/commons/scxml/EventDispatcher.html">EventDispatcher</a>
      interface for wiring the behavior of SCXML &lt;send&gt; and
-     &lt;cancel&gt; actions. This allows users to define custom "targettypes"
+     &lt;cancel&gt; actions. This allows users to define custom target "types"
      as long as they handle the callbacks on the <code>EventDispatcher</code>
      implementation provided to the executor. The introductory section on
      using Commons SCXML has a brief discussion on

Modified: commons/proper/scxml/branches/J6/xdocs/guide/using-commons-scxml.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/xdocs/guide/using-commons-scxml.xml?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/xdocs/guide/using-commons-scxml.xml (original)
+++ commons/proper/scxml/branches/J6/xdocs/guide/using-commons-scxml.xml Thu Jul 16 03:25:20 2009
@@ -116,8 +116,8 @@
 
     <p>SCXML includes the &lt;send&gt; action to "dispatch" an event of choice
     (including whatever payload) to a specified target (of a specified
-    targettype). The payload is delivered in the form of a namelist,
-    which can be considered as params for the event target.</p>
+    type). The payload is delivered in the form of a namelist, which can be
+    considered as params for the event target.</p>
 
     <p>The callbacks are received on the
     <a href="../apidocs/org/apache/commons/scxml/EventDispatcher.html">EventDispatcher</a>
--- commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/SCInstance.java (original)
+++ commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/SCInstance.java Thu Jul 16 03:25:20 2009
@@ -66,7 +66,7 @@
 
     /**
      * The <code>Invoker</code> classes <code>Map</code>, keyed by
      * &lt;invoke&gt; target types (specified using "targettype" attribute).
      */
     private final Map<String, Class<? extends Invoker>> invokerClasses;
 
@@ -279,24 +279,24 @@
     /**
      * Register an {@link Invoker} class for this target type.
      *
-     * @param targettype The target type (specified by "targettype"
-     *                   attribute of &lt;invoke&gt; tag).
+     * @param type The target type (specified by "type" attribute of
+     *             &lt;invoke&gt; tag).
      * @param invokerClass The <code>Invoker</code> <code>Class</code>.
      */
-    void registerInvokerClass(final String targettype,
+    void registerInvokerClass(final String type,
             final Class<? extends Invoker> invokerClass) {
-        invokerClasses.put(targettype, invokerClass);
+        invokerClasses.put(type, invokerClass);
     }
 
     /**
      * Remove the {@link Invoker} class registered for this target
      * type (if there is one registered).
      *
-     * @param targettype The target type (specified by "targettype"
-     *                   attribute of &lt;invoke&gt; tag).
+     * @param type The target type (specified by "type" attribute of
+     *             &lt;invoke&gt; tag).
      */
-    void unregisterInvokerClass(final String targettype) {
-        invokerClasses.remove(targettype);
+    void unregisterInvokerClass(final String type) {
+        invokerClasses.remove(type);
     }
 
     /**
@@ -305,19 +305,19 @@
      * returned if and only if the <code>TransitionTarget</code> is
      * currently active and contains an &lt;invoke&gt; child.
      *
-     * @param targettype The type of the target being invoked.
+     * @param type The type of the target being invoked.
      * @return An {@link Invoker} for the specified type, if an
      *         invoker class is registered against that type,
      *         <code>null</code> otherwise.
      * @throws InvokerException When a suitable {@link Invoker} cannot
      *                          be instantiated.
      */
-    public Invoker newInvoker(final String targettype)
+    public Invoker newInvoker(final String type)
     throws InvokerException {
-        Class<? extends Invoker> invokerClass = invokerClasses.get(targettype);
+        Class<? extends Invoker> invokerClass = invokerClasses.get(type);
         if (invokerClass == null) {
-            throw new InvokerException("No Invoker registered for "
-                + "targettype \"" + targettype + "\"");
+            throw new InvokerException("No Invoker registered for type \""
+                + type + "\"");
         }
         Invoker invoker = null;
         try {
@@ -66,7 +66,7 @@
     /**
      * The <code>Invoker</code> classes <code>Map</code>, keyed by
-     * &lt;invoke&gt; target types (specified using "targettype" attribute).
+     * &lt;invoke&gt; target types (specified using "type" attribute).
      */
     private final Map<String, Class<? extends Invoker>> invokerClasses;

Modified: commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/SCXMLExecutor.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/SCXMLExecutor.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================
--- commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/ModelUpdater.java (original)
+++ commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/ModelUpdater.java Thu Jul 16 03:25:20 2009
@@ -165,9 +165,9 @@
             logAndThrowModelError(ERR_STATE_BAD_CONTENTS, new Object[] {getStateName(s)});
         }
         if (inv != null) {
-            String ttype = inv.getTargettype();
-            if (ttype == null || ttype.trim().length() == 0) {
-                logAndThrowModelError(ERR_INVOKE_NO_TARGETTYPE,
+            String type = inv.getType();
+            if (type == null || type.trim().length() == 0) {
+                logAndThrowModelError(ERR_INVOKE_NO_TYPE,
                     new Object[] {getStateName(s)});
             }
             String src = inv.getSrc();
@@ -403,11 +403,11 @@
         + " belonging to \"{1}\" is also a history";
 
     /**
      * Error message when an &lt;invoke&gt; does not specify a "targettype"
      * attribute.
      */
-    private static final String ERR_INVOKE_NO_TARGETTYPE = "{0} contains "
-        + "<invoke> with no \"targettype\" attribute specified.";
+    private static final String ERR_INVOKE_NO_TYPE = "{0} contains "
+        + "<invoke> with no \"type\" attribute specified.";
 
     /**
      * Error message when an &lt;invoke&gt; does not specify a "src"
@@ -403,11 +403,11 @@
 
     /**
-     * Error message when an &lt;invoke&gt; does not specify a "targettype"
+     * Error message when an &lt;invoke&gt; does not specify a "type"
      * attribute.
      */

Modified: commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/SCXMLReader.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/branches/J6/src/main/java/org/apache/commons/scxml/io/SCXMLReader.java?rev=794504&r1=794503&r2=794504&view=diff
==============================================================================